<?php

declare(strict_types=1);

namespace Drupal\persistent_visitor_parameters\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\persistent_visitor_parameters\PersistenceManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Persistent Visitor Parameters routes.
 */
final class PersistentVisitorParametersDebugController extends ControllerBase {

  /**
   * The controller constructor.
   */
  public function __construct(
    private readonly PersistenceManager $persistenceManager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('persistent_visitor_parameters.persistence_manager'),
    );
  }

  /**
   * Builds the response.
   */
  public function __invoke(): array {
    $persistedParameters = $this->persistenceManager->loadPersistedParameters();
    $build['help'] = [
      '#type' => 'item',
      '#plain_text' => "This debug page shows the persistent visitor parameters currently present in this users storage.",
    ];
    $build['content'] = [
      '#type' => 'inline_template',
      // @todo Remove 2nd sentence, once we support authenticated users!
      '#template' => "{% if output %}<pre>{{ output }}</pre>{% else %}{{'No persistent visitor parameters present (for the current user). <em>Authenticated users are not yet supported!</em>'|t}}{% endif %}",
      '#context' => [
        'output' => print_r($persistedParameters, TRUE),
      ],
    ];

    return $build;
  }

}
