<?php

namespace Drupal\persistent_visitor_parameters\EventSubscriber;

use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Drupal\Core\Render\HtmlResponse;
use Drupal\Core\Session\AccountInterface;
use Drupal\persistent_visitor_parameters\PersistenceManager;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * This class sets the cookie on kernel response.
 */
class ResponseSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritDoc}
   */
  public function __construct(protected PersistenceManager $persistenceManager, protected AccountInterface $currentUser) {}

  /**
   * {@inheritDoc}
   */
  public function onRespond(ResponseEvent $event) {
    // Set the cookie only for anonymous users:
    if (!$this->currentUser->isAnonymous()) {
      return;
    }

    // Only handle main request:
    if (!$event->isMainRequest()) {
      return;
    }

    // Only process Html Responses.
    $response = $event->getResponse();
    if (!$response instanceof HtmlResponse) {
      return;
    }

    // Persist the current request parameters (if applies):
    $this->persistenceManager->persistMatchingRequestParameters($response);
  }

  /**
   * {@inheritDoc}
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::RESPONSE][] = ['onRespond'];
    return $events;
  }

}
