<?php

declare(strict_types=1);

namespace Drupal\persistent_visitor_parameters;

use Drupal\Core\Render\HtmlResponse;

/**
 * The persistor interface.
 */
interface PersistorInterface {

  /**
   * Stores the data to persist.
   *
   * @param array $data
   *   The data to persist.
   * @param \Drupal\Core\Render\HtmlResponse $response
   *   The HTML response. * Required for some of the persistors to modify the
   *   current response.
   *   @todo We should try to get rid of this parameter that is only
   *   required for Cookies. Maybe we can instead get the response
   *   somewhere from the current request?
   *
   * @return bool
   *   True if something was persisted, false otherwise.
   */
  public function persist(array $data, ?HtmlResponse $response): bool;

  /**
   * Returns the persisted values as array, NULL if not existing.
   *
   * @return array|null
   *   Array of the persisted values, if present, else NULL.
   */
  public function load(): ?array;

  /**
   * Clears the storage (if supported).
   *
   * @return bool
   *   TRUE if successful, FALSE if not or not supported.
   */
  public function clear(): bool;

}
