<?php

declare(strict_types=1);

namespace Drupal\persistent_visitor_parameters;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Render\HtmlResponse;
use Drupal\Core\TempStore\PrivateTempStore;
use Drupal\Core\TempStore\PrivateTempStoreFactory;

/**
 * The private temp store persistor.
 */
class PersistorPrivateTempStore extends PersistorBase implements PersistorInterface {

  /**
   * The Private Temp Store.
   *
   * @var \Drupal\Core\TempStore\PrivateTempStore
   */
  protected PrivateTempStore $tempStore;

  /**
   * The private temp store.
   *
   * @var \Drupal\Core\TempStore\PrivateTempStore
   */
  public function __construct(
    protected readonly ConfigFactoryInterface $configFactory,
    PrivateTempStoreFactory $tempStoreFactory,
  ) {
    $this->tempStore = $tempStoreFactory->get('persistent_visitor_parameters');
    $this->config = $configFactory->get('persistent_visitor_parameters.settings');
  }

  /**
   * {@inheritDoc}
   */
  public function clear(): bool {
    $this->tempStore->delete($this->getPersistorKey());
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function persist(array $data, ?HtmlResponse $response): bool {
    // Note: For anonymous users this value will only last within the active
    // session. Values are lost as soon as the user navigates away.
    $this->tempStore->set($this->getPersistorKey(), $data);
    return !empty($this->tempStore->get($this->getPersistorKey()));
  }

  /**
   * {@inheritdoc}
   */
  public function load(): ?array {
    $data = $this->tempStore->get($this->getPersistorKey());
    return $data;
  }

}
