<?php

declare(strict_types=1);

namespace Drupal\persistent_visitor_parameters;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Render\HtmlResponse;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * The session persistor.
 */
class PersistorSession extends PersistorBase implements PersistorInterface {

  public function __construct(
    protected readonly ConfigFactoryInterface $configFactory,
    protected readonly RequestStack $requestStack,
  ) {
    $this->config = $configFactory->get('persistent_visitor_parameters.settings');
  }

  /**
   * {@inheritDoc}
   */
  public function clear(): bool {
    $session = $this->requestStack->getSession();
    $session->remove($this->getPersistorKey());
    $session->save();
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function persist(array $data, ?HtmlResponse $response): bool {
    $session = $this->requestStack->getSession();
    $session->set($this->getPersistorKey(), $data);
    $session->save();
    return !empty($session->get($this->getPersistorKey()));
  }

  /**
   * {@inheritdoc}
   */
  public function load(): ?array {
    $session = $this->requestStack->getSession();
    return $session->get($this->getPersistorKey());
  }

}
