<?php

namespace Drupal\Tests\persistent_visitor_parameters\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * This class provides methods for testing persistent_visitor_parameters.
 *
 * @group persistent_visitor_parameters
 */
class FormFunctionalTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'test_page_test',
    'persistent_visitor_parameters',
  ];

  /**
   * A user with authenticated permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * The cookie manager service.
   *
   * @var \Drupal\persistent_visitor_parameters\PersistenceManager
   */
  protected $persistenceManager;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->config('system.site')->set('page.front', '/test-page')->save();
    $this->user = $this->drupalCreateUser([]);
    $this->persistenceManager = \Drupal::service('persistent_visitor_parameters.persistence_manager');
  }

  /**
   * Test if the cookie won't get set for admin users.
   */
  public function testPersistedParametersAdmin() {
    $this->drupalLogin($this->rootUser);
    $session = $this->assertSession();
    $page = $this->getSession()->getPage();
    $this->drupalGet('/admin/config/people/persistent-visitor-parameters/settings');
    $page->fillField('get_parameters', 'utm_source|utm_medium|utm_campaign|utm_term|utm_content');
    $page->fillField('server_parameters', 'HTTP_REFERER|HTTP_USER_AGENT');
    $page->pressButton('Save configuration');
    $session->pageTextContains('The configuration options have been saved.');

    // @todo check the value after save and also test all other values.
  }

}
