<?php

namespace Drupal\Tests\persistent_visitor_parameters\Functional;

/**
 * This class provides methods for testing persistent_visitor_parameters.
 *
 * @group persistent_visitor_parameters
 */
class PersistorNullFunctionalTest extends PersistorTestBase {

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->config('persistent_visitor_parameters.settings')
      ->set('persistor', 'persistor_null')
      ->save();
  }

  /**
   * Tests persisting as authenticated user with first_touch method.
   */
  public function testPersistAuthenticatedFirstTouch() {
    // We don't support tracking for logged in users yet:
    $this->drupalGet('<front>', [
      'query' => $this->getGetParameters1(),
    ]);

    // @improve: We currently test against the debug page
    // because the test runner has a different session than the
    // actually tested user.
    // So we can't simply run
    // $this->persistenceManager->loadPersistedParameters();
    // in the tests, as it would always return NULL.
    // Maybe it's possible to instead use a mock object that is then filled
    // by the test or whatever, but after investing several hours looking
    // for solutions and documentation we gave up...
    // This works good enough for now. Please teach us! ;)
    $this->drupalGet('/admin/config/people/persistent-visitor-parameters/debug');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Persistent Visitor Parameters Debug');
    $this->assertSession()->pageTextNotContains('Array');
  }

  /**
   * Tests persisting as anonymous user with first_touch method.
   */
  public function testPersistAnonymousFirstTouch() {
    // Make a first call:
    $this->drupalGet('<front>', [
      'query' => $this->getGetParameters1(),
    ]);
    // For the NULL persistor we expect empty results:
    $this->drupalGet('/admin/config/people/persistent-visitor-parameters/debug');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Persistent Visitor Parameters Debug');
    $this->assertSession()->pageTextNotContains('Array');

    // Make a second call:
    $this->drupalGet('<front>', [
      'query' => $this->getGetParameters2(),
    ]);
    $this->drupalGet('/admin/config/people/persistent-visitor-parameters/debug');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Persistent Visitor Parameters Debug');
    $this->assertSession()->pageTextNotContains('Array');
  }

  /**
   * Tests persisting as authenticated user with last_touch method.
   */
  public function testPersistAuthenticatedLastTouch() {
    // We don't support tracking for logged in users yet:
    $this->drupalGet('<front>', [
      'query' => $this->getGetParameters1(),
    ]);

    // @improve: We currently test against the debug page
    // because the test runner has a different session than the
    // actually tested user.
    // So we can't simply run
    // $this->persistenceManager->loadPersistedParameters();
    // in the tests, as it would always return NULL.
    // Maybe it's possible to instead use a mock object that is then filled
    // by the test or whatever, but after investing several hours looking
    // for solutions and documentation we gave up...
    // This works good enough for now. Please teach us! ;)
    $this->drupalGet('/admin/config/people/persistent-visitor-parameters/debug');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Persistent Visitor Parameters Debug');
    $this->assertSession()->pageTextNotContains('Array');
  }

  /**
   * Tests persisting as anonymous user with last_touch method.
   */
  protected function testPersistAnonymousLastTouch() {
    // Make a first call:
    $this->drupalGet('<front>', [
      'query' => $this->getGetParameters1(),
    ]);
    // For the NULL persistor we expect empty results:
    $this->drupalGet('/admin/config/people/persistent-visitor-parameters/debug');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Persistent Visitor Parameters Debug');
    $this->assertSession()->pageTextNotContains('Array');

    // Make a second call:
    $this->drupalGet('<front>', [
      'query' => $this->getGetParameters2(),
    ]);
    // For the NULL persistor we expect empty results:
    $this->drupalGet('/admin/config/people/persistent-visitor-parameters/debug');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Persistent Visitor Parameters Debug');
    $this->assertSession()->pageTextNotContains('Array');
  }

  // Other methods are inherited from PersistorTestBase!
}
